<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/*
Plugin Name: Taxonomies exporter for seo
Plugin URI: https://modir-shop.com/
Description: این افزونه دسته ها، برچسب ها و برندها را به صورت درختی، همرا با تعداد محصولات موجود در هر دسته را نمایش میدهد.
Version: 1.0
Requires PHP: 8.1
Author: مدیر شاپ
Author URI: https://modir-shop.com/
*/

add_action( 'admin_menu', function () {
	add_menu_page(
		'استخراج دسته و محصولات',
		'استخراج دسته و محصولات',
		'manage_options',
		'mks-taxonomies-exporter',
		'mks_show_exporter_page'
	);

	add_action( 'admin_enqueue_scripts', function () {
		if ( isset( $_REQUEST['page'] ) && $_REQUEST['page'] == 'mks-taxonomies-exporter' ) {
			wp_enqueue_style(
				'mks-exporter-css',
				plugin_dir_url( __FILE__ ) . 'assets/css/mks-exporter.css'
			);
		}
	} );

} );

if ( ! function_exists( 'mks_show_exporter_page' ) ) {
	function mks_show_exporter_page() {


		$type = 'product_cat';

		if ( isset( $_REQUEST['mks_exporter_type'] ) && ! empty( $_REQUEST['mks_exporter_type'] ) ) {
			$type = $_REQUEST['mks_exporter_type'];
		}

		include __DIR__ . '/views/index.php';
	}
}

if ( ! function_exists( 'mks_exporter_get_items' ) ) {
	function mks_exporter_get_items( $type ) {

		$data = [];
		$args = [
			'taxonomy'   => $type,
			'hide_empty' => false,
			'parent'     => 0
		];

		$products_args = [
			'fields'   => 'ids',
			'tax_query' => [
				[
					'taxonomy' => $type,
					'field'    => 'term_id',
					'terms'    => '',
					'operator' => 'IN'
				]
			]
		];

		// Level first
		foreach ( get_terms( $args ) as $tax ) {

			$children = get_terms( [
				'taxonomy'   => $type,
				'hide_empty' => false,
				'parent'     => $tax->term_id
			] );

			// Level second
			if ( ! empty( $children ) ) {
				foreach ( $children as $child ) {

					$subs = get_terms( [
						'taxonomy'   => $type,
						'hide_empty' => false,
						'parent'     => $child->term_id
					] );

					// Level third
					if ( ! empty( $subs ) ) {
						foreach ( $subs as $sub ) {

							$products_args['tax_query'][0]['terms'] = $sub->term_id;
							$in_stock = 0;
							$out_of_stock = 0;

							foreach ((new WP_Query($products_args))->get_posts() as $post) {
								$status = get_post_meta($post, '_stock_status', true);
								$status == 'instock' ? $in_stock++ : $out_of_stock++;
							}

							$data[] = [
								1              => $tax->name,
								2              => $child->name,
								3              => $sub->name,
								'link_1' => get_term_link($tax->term_id),
								'link_2' => get_term_link($child->term_id),
								'link_3' => get_term_link($sub->term_id),
								'count'        => $sub->count,
								'instock'      => $in_stock,
								'out_of_stock' => $out_of_stock,
                                'desc' => str_word_count($sub->description, 0 , 'ابپتثجچ‌حخدذرز‌ژس‌شصضطظعغفقکگلمنوهیءآاًهٔه')
							];
						}
					} else {

						$products_args['tax_query'][0]['terms'] = $child->term_id;
						$in_stock = 0;
						$out_of_stock = 0;

						foreach ((new WP_Query($products_args))->get_posts() as $post) {
							$status = get_post_meta($post, '_stock_status', true);
							$status == 'instock' ? $in_stock++ : $out_of_stock++;
						}

						$data[] = [
							1       => $tax->name,
							2       => $child->name,
							'link_1' => get_term_link($tax->term_id),
							'link_2' => get_term_link($child->term_id),
							'count' => $child->count,
							'instock'      => $in_stock,
							'out_of_stock' => $out_of_stock,
                            'desc' => str_word_count($child->description, 0 , 'ابپتثجچ‌حخدذرز‌ژس‌شصضطظعغفقکگلمنوهیءآاًهٔه')
						];
					}

				}
			} else {

				$products_args['tax_query'][0]['terms'] = $tax->term_id;
                $in_stock = 0;
                $out_of_stock = 0;

                foreach ((new WP_Query($products_args))->get_posts() as $post) {
                    $status = get_post_meta($post, '_stock_status', true);

	                $status == 'instock' ? $in_stock++ : $out_of_stock++;
                }

				$data[] = [
					1 => $tax->name,
                    'link_1' => get_term_link($tax->term_id),
					'count' => $tax->count,
					'instock'      => $in_stock,
					'out_of_stock' => $out_of_stock,
					'desc' => str_word_count($tax->description,  0 , 'ابپتثجچ‌حخدذرز‌ژس‌شصضطظعغفقکگلمنوهیءآاًهٔه')
				];
			}

		}

		return $data;
	}
}

if ( ! function_exists( 'mks_exporter_show_items' ) ) {
	function mks_exporter_show_items( $type ) {

		$counter = 1;

		foreach ( mks_exporter_get_items( $type ) as $key => $item ) :?>

            <tr>
                <td><?php echo $counter ?></td>
                <td><a target="_blank" href="<?php echo $item['link_1'] ?? '' ?>"><?php echo $item[1] ?? '' ?></a></td>
                <td><a target="_blank" href="<?php echo $item['link_2'] ?? '' ?>"><?php echo $item[2] ?? '' ?></a></td>
                <td><a target="_blank" href="<?php echo $item['link_3'] ?? '' ?>"><?php echo $item[3] ?? '' ?></a></td>
                <td></td>
                <td><?php echo $item['count'] ?? '' ?></td>
                <td><?php echo $item['instock'] ?? '' ?></td>
                <td><?php echo $item['out_of_stock'] ?? '' ?></td>
                <td></td>
                <td><?php echo $item['desc'] ?? '' ?></td>
            </tr>

			<?php $counter ++; endforeach;

	}
}

